Class SpeechInteraction extends UWinInteraction;

var() localized string SpeechOptions[6],CancelSpeechStr,NextPart,EveryoneStr;
var byte SubOptionNum,InitSubMenu,MenuShowOffset,MenuSelections[3];
struct FSpeechLineType
{
	var int ID;
	var string Text;
};
var FSpeechLineType Lines[32];
var byte NumLines;
var name TauntCommand[4];
var localized string PhysicalTaunts[4];

const PanelBoarder=3.f;
const PanelBoarderTw=6.f;

function PostRender( Canvas Canvas )
{
	local class<ChallengeVoicePack> VPack;

	VPack = class<ChallengeVoicePack>(Canvas.Viewport.Actor.PlayerReplicationInfo.VoiceType);
	if( VPack==None )
	{
		CancelSpeech();
		return;
	}
	if( InitSubMenu!=SubOptionNum )
	{
		InitSubMenu = SubOptionNum;
		MenuShowOffset = 0;
		if( SubOptionNum==0 )
			FillBasicSpeech();
		else if( SubOptionNum==1 )
			FillSubSelection(VPack);
		else if( SubOptionNum==2 )
			FillPlayers();
	}
	if( bRequestRender )
		DrawSpeechMenu(Canvas); // Make sure menu is still available
}
function OpenSpeech()
{
	bRequestRender = true;
	bRequestInput = true;
	SubOptionNum = 0;
	InitSubMenu = 255;
}
function CancelSpeech()
{
	bRequestRender = false;
	bRequestInput = false;
}
function FillBasicSpeech()
{
	local byte i;

	NumLines = ArrayCount(SpeechOptions);
	for( i=0; i<NumLines; i++ )
	{
		Lines[i].ID = i;
		Lines[i].Text = SpeechOptions[i];
	}
}
function FillSubSelection( class<ChallengeVoicePack> VPack )
{
	local byte i;

	switch( MenuSelections[0] )
	{
	case 0:
		NumLines = VPack.Default.numAcks;
		break;
	case 1:
		NumLines = VPack.Default.numFFires;
		break;
	case 2:
		FillOrders(VPack);
		return;
	case 3:
		NumLines = VPack.Default.numTaunts;
		break;
	case 4:
		FillOther(VPack);
		return;
	case 5:
		NumLines = ArrayCount(PhysicalTaunts);
		break;
	default:
		NumLines = 0;
		return;
	}
	for( i=0; i<NumLines; i++ )
	{
		Lines[i].ID = i;
		switch( MenuSelections[0] )
		{
		case 0:
			Lines[i].Text = VPack.Static.GetAckString(i);
			break;
		case 1:
			Lines[i].Text = VPack.Static.GetFFireString(i);
			break;
		case 3:
			Lines[i].Text = VPack.Static.GetTauntString(i);
			break;
		default:
			Lines[i].Text = PhysicalTaunts[i];
			break;
		}
	}
}
function FillOrders( class<ChallengeVoicePack> VPack )
{
	local byte i;

	NumLines = 0;
	if( Viewport.Actor.GameReplicationInfo==None )
		return;
	for( i=0; i<9; i++ )
	{
		Lines[NumLines].Text = VPack.Static.GetOrderString(i,Viewport.Actor.GameReplicationInfo.GameName);
		if( Len(Lines[NumLines].Text)>0 )
		{
			Lines[NumLines].ID = NumLines;
			NumLines++;
		}
	}
}
function FillOther( class<ChallengeVoicePack> VPack )
{
	local byte i;

	NumLines = 0;
	for( i=0; i<32; i++ )
	{
		Lines[i].ID = i;
		Lines[i].Text = VPack.Static.GetOtherString(i);
		if( Len(Lines[NumLines].Text)==0 )
			break;
		NumLines++;
	}
}
function FillPlayers()
{
	local byte SelectedTeam,i;
	local TournamentGameReplicationInfo TGRI;

	MenuSelections[2] = 255;
	NumLines = 0;
	TGRI = TournamentGameReplicationInfo(Viewport.Actor.GameReplicationInfo);
	if( TGRI==None )
		return;
	switch( MenuSelections[0] )
	{
	case 2:
		if( !TGRI.bTeamGame )
		{
			SendOutMessage();
			return;
		}
		else SelectedTeam = Viewport.Actor.PlayerReplicationInfo.Team;
		break;
	default:
		SendOutMessage();
		return;
	}
	Lines[NumLines].ID = 255;
	Lines[NumLines++].Text = EveryoneStr;
	for( i=0; i<32; i++ )
	{
		if( TGRI.PRIArray[i]==None || TGRI.PRIArray[i]==Viewport.Actor.PlayerReplicationInfo || TGRI.PRIArray[i].bIsSpectator || (SelectedTeam!=255 && SelectedTeam!=TGRI.PRIArray[i].Team) )
			continue;
		Lines[NumLines].ID = TGRI.PRIArray[i].TeamID;
		Lines[NumLines++].Text = TGRI.PRIArray[i].PlayerName;
	}
}
function SendOutMessage()
{
	if( MenuSelections[0]==5 )
		Viewport.Actor.Taunt(TauntCommand[MenuSelections[1]]);
	else Viewport.Actor.Speech(MenuSelections[0],MenuSelections[1],MenuSelections[2]);
	CancelSpeech();
}
function bool KeyEvent( byte Key, byte Action, FLOAT Delta )
{
	if( Key==Console.EInputKey.IK_Escape )
	{
		CancelSpeech();
		return true;
	}
	else if( Key>=Console.EInputKey.IK_0 && Key<=Console.EInputKey.IK_9 )
	{
		if( Action==Console.EInputAction.IST_Press )
		{
			if( Key==Console.EInputKey.IK_0 )
			{
				if( SubOptionNum==0 )
					CancelSpeech();
				else SubOptionNum--;
			}
			else HandleOption(Key-Console.EInputKey.IK_1);
		}
		return true;
	}
	Return False;
}
function HandleOption( byte OptNum )
{
	if( OptNum==8 )
	{
		if( NumLines>((MenuShowOffset+1)*8) )
			MenuShowOffset++;
		return;
	}
	OptNum+=(MenuShowOffset*8);
	if( OptNum>NumLines )
		return;
	MenuSelections[SubOptionNum++] = Lines[OptNum].ID;
	if( SubOptionNum==ArrayCount(MenuSelections) )
		SendOutMessage();
}
final function DrawSpeechMenu( Canvas C )
{
	local float XL,YL,OrgX;
	local int YSize,YOffset,i,YDrawOffset,Idx;

	if( C.Viewport.Actor.PlayerReplicationInfo!=None && C.Viewport.Actor.PlayerReplicationInfo.Team<4 )
		C.DrawColor = Class'UnrealHUD'.Default.TeamColor[C.Viewport.Actor.PlayerReplicationInfo.Team];
	else C.DrawColor = Class'UnrealHUD'.Default.TeamColor[0];

	if( ChallengeHUD(C.Viewport.Actor.MyHUD)!=None )
		C.Font = ChallengeHUD(C.Viewport.Actor.MyHUD).MyFonts.GetMediumFont(C.ClipX);
	else C.Font = Font'WhiteFont';

	C.TextSize("HELLO",XL,YL);
	YSize = YL+12.f;
	C.Style = 1;
	YOffset = Min((C.ClipY*0.7-100.f),C.ClipY-(YSize*10));
	OrgX = C.ClipX;
	YDrawOffset = YOffset+(YSize*0.5-YL*0.5);
	for( i=0; i<10; i++ )
	{
		C.ClipX = 250.f;
		DrawBoxAt(C,0,YOffset+(i*YSize),C.ClipX,YSize);
		C.ClipX = 245.f;
		C.CurX = 5;
		C.CurY = YDrawOffset+(i*YSize);

		if( i<9 )
		{
			Idx = i+(MenuShowOffset*8);
			if( Idx<NumLines )
			{
				if( i==8 && (NumLines>(Idx+1)) )
					C.DrawTextClipped("9 -"@NextPart);
				else C.DrawTextClipped((i+1)@"-"@Lines[Idx].Text);
			}
			else
			{
				C.DrawTextClipped("0 -"@CancelSpeechStr);
				break;
			}
		}
		else C.DrawTextClipped("0 -"@CancelSpeechStr);
	}
	C.ClipX = OrgX;
}
final function DrawBoxAt( Canvas C, float X, float Y, float XS, float YS )
{
	local color CO;
	local byte OldStyle;

	OldStyle = C.Style;
	C.Style = C.Viewport.Actor.ERenderStyle.STY_Translucent;
	CO = C.DrawColor;
	C.SetPos(X,Y);
	C.DrawTile(Texture'FacePanel0',XS,PanelBoarder,0,0,1,1);
	C.SetPos(X,Y+PanelBoarder);
	C.DrawTile(Texture'FacePanel0',PanelBoarder,YS-PanelBoarderTw,0,0,1,1);
	C.SetPos(X,Y+YS-PanelBoarder);
	C.DrawTile(Texture'FacePanel0',XS,PanelBoarder,0,0,1,1);
	C.SetPos(X+XS-PanelBoarder,Y+PanelBoarder);
	C.DrawTile(Texture'FacePanel0',PanelBoarder,YS-PanelBoarderTw,0,0,1,1);
	C.DrawColor.R = C.DrawColor.R*0.4;
	C.DrawColor.G = C.DrawColor.G*0.4;
	C.DrawColor.B = C.DrawColor.B*0.4;
	C.SetPos(X+PanelBoarder,Y+PanelBoarder);
	C.DrawTile(Texture'FacePanel0',XS-PanelBoarderTw,YS-PanelBoarderTw,0,0,1,1);
	C.DrawColor = CO;
	C.Style = OldStyle;
}

defaultproperties
{
				SpeechOptions(0)="Acknowledge"
				SpeechOptions(1)="Friendly Fire"
				SpeechOptions(2)="Orders"
				SpeechOptions(3)="Taunts"
				SpeechOptions(4)="Other/Misc"
				SpeechOptions(5)="Gesture"
				CancelSpeechStr="Cancel"
				NextPart="More..."
				EveryoneStr="All"
				TauntCommand(0)="Victory1"
				TauntCommand(1)="Thrust"
				TauntCommand(2)="Taunt1"
				TauntCommand(3)="Wave"
				PhysicalTaunts(0)="Basic Taunt"
				PhysicalTaunts(1)="Pelvic Thrust"
				PhysicalTaunts(2)="Victory Dance"
				PhysicalTaunts(3)="Wave"
}
